REM ---------------------------------------------------------------
REM            CONFIG BOARD
REM ---------------------------------------------------------------
REM Set the default config board.
SET DEFAULT_CONFIG_BOARD=%TCC_HOME%\system\default.configuration_brd.xml
If "%CONFIG_BOARD%"=="" (
	SET CONFIG_BOARD=%DEFAULT_CONFIG_BOARD%
) 
If "%CONFIG_BOARDS_FOLDER%"=="" (
	SET CONFIG_BOARD=%DEFAULT_CONFIG_BOARD%
) 

REM If CONFIG_BOARD is only a filename, prefix it with CONFIG_BOARDS_FOLDER.
echo %CONFIG_BOARD%|findstr \\ >nul:
IF %errorlevel%==1 (
	SET CONFIG_BOARD=%CONFIG_BOARDS_FOLDER%\%CONFIG_BOARD%
)

REM ---------------------------------------------------------------
REM            VALIDATIONS
REM ---------------------------------------------------------------
If "%TCC_HOME%"=="" (
	echo ### ERROR - TCC_HOME variable is mandatory. ###
	pause
	exit 1
)
If Not Exist "%TCC_HOME%" (
	echo ### ERROR - The TCC_HOME path "%TCC_HOME%" does not exist. ###
	pause
	exit 1
)
If "%JAVA_HOME%"=="" (
	echo ### ERROR - JAVA_HOME variable is mandatory. ###
	pause
	exit 1
)
If Not Exist "%JAVA_HOME%" (
	echo ### ERROR - The JAVA_HOME path "%JAVA_HOME%" does not exist. ###
	pause
	exit 1
)
If Not Exist "%CONFIG_BOARD%" (
	echo ### ERROR - The configuration board file "%CONFIG_BOARD%" does not exist. ###
	pause
	exit 1
)

REM ---------------------------------------------------------------
REM            CREATE FOLDERS
REM ---------------------------------------------------------------
IF NOT EXIST "%TEMP_FOLDER%" mkdir %TEMP_FOLDER%

REM ---------------------------------------------------------------
REM            READ CONFIGURATION BOARD
REM ---------------------------------------------------------------
call :GetDefaultHost TALEO_HOST
call :GetSymbolValue ALERTING_MAIL_FROM
call :GetSymbolValue FTP_HOST
call :GetSymbolValue FTP_PORT
call :GetSymbolValue FTP_USER
call :GetSymbolValue FTP_PASSWORD
call :GetSymbolValue FTP_INBOUND_FOLDER

REM ---------------------------------------------------------------
REM            MULTI-ZONE SETTINGS
REM ---------------------------------------------------------------
REM Indicate if execution reads and writes files in zone-specific folders (true/false).  
REM Recommended value is false, since it is usually better to have seperate TCCTouchpoints folders per environment. 
SET MULTI_ZONE=false

IF "%MULTI_ZONE%"=="true" (
	SET LOG_FOLDER=%LOG_FOLDER%\%TALEO_HOST%
	SET LASTRUNDATE_FOLDER=%LASTRUNDATE_FOLDER%\%TALEO_HOST%
	SET MONITOR_FOLDER=%MONITOR_FOLDER%\%TALEO_HOST%
	SET NETCHANGE_REPOSITORY=%NETCHANGE_REPOSITORY%\%TALEO_HOST%
	SET INBOUND_FOLDER=%INBOUND_FOLDER%\%TALEO_HOST%
	SET OUTBOUND_FOLDER=%OUTBOUND_FOLDER%\%TALEO_HOST%
	SET ARCHIVE_FOLDER=%ARCHIVE_FOLDER%\%TALEO_HOST%
	SET ERROR_FOLDER=%ERROR_FOLDER%\%TALEO_HOST%
	SET TEMP_FOLDER=%TEMP_FOLDER%\%TALEO_HOST%
)

REM ---------------------------------------------------------------
REM            SET DATE AND TIME VARIABLES
REM ---------------------------------------------------------------
Call core/GetDateTime.bat

REM Build the NOW variable.
set NOW=%YYYY%%MM%%DD%_%HH%%MI%%SS%

REM Build the TODAY variable.
set TODAY=%YYYY%%MM%%DD%

REM ---------------------------------------------------------------
REM            SET DEFAULT VALUES
REM ---------------------------------------------------------------
IF "%NB_RETRIES%"=="" SET NB_RETRIES=0

REM ---------------------------------------------------------------
REM            RESET THE ERRORLEVEL
REM ---------------------------------------------------------------
REM This simple trick resets the ERRORLEVEL to 0.
REM Note that "Set ERRORLEVEL=0" does not do, because once you set this variable explicitly 
REM then any command you run after will not be able to change the value of the %ERRORLEVEL%.
verify >nul


GOTO :EOF
REM ---------------------------------------------------------------
REM            FUNCTIONS
REM ---------------------------------------------------------------
:GetDefaultHost var -- Get the value of the default host in the configuration board file.
::									-- var [in/out] - The variable to set the value.
SETLOCAL ENABLEDELAYEDEXPANSION
set var=!%~1!
path "%JAVA_HOME%\bin\"
for /F "delims=" %%a in ('java.exe -jar "%TCC_HOME%\lib\saxon10.jar" "%CONFIG_BOARD%" ..\xsl\GetDefaultHost.xsl') do set value=%%a
( ENDLOCAL & REM RETURN VALUES
	SET %~1=%value%
)
EXIT /b

:GetSymbolValue var defafult -- Get the value of a symbol in the configuration board file.
::           		   				   -- var [in/out] - The variable to set the value and the symbol name.
::           		   				   -- default [in, opt] - The default value.
SETLOCAL ENABLEDELAYEDEXPANSION
set var=!%~1!
set name=%~1
set default=%~2
path "%JAVA_HOME%\bin\"
for /F "delims=" %%a in ('java.exe -jar "%TCC_HOME%\lib\saxon10.jar" "%CONFIG_BOARD%" ..\xsl\GetSymbolValue.xsl name^=!name!') do set value=%%a
IF "%value%"=="" (
	SET value=%default%
)
( ENDLOCAL & REM RETURN VALUES
	SET %~1=%value%
)
EXIT /b
